@@ -3,7 +3,6 @@
 
 """Test Hdfs client interactions with HDFS."""
 
-from hdfs import get_client_from_alias
 from hdfs.util import Config, temppath
 from hdfs.client import *
 from ConfigParser import NoOptionError, NoSectionError
@@ -27,11 +26,11 @@ class TestLoad(object):
   """Test client loader."""
 
   def test_bare(self):
-    client = Client.load(None, {'url': 'foo'})
+    client = Client._from_options(None, {'url': 'foo'})
     ok_(isinstance(client, Client))
 
   def test_kerberos(self):
-    client = Client.load('KerberosClient', {'url': 'foo'})
+    client = Client._from_options('KerberosClient', {'url': 'foo'})
     ok_(isinstance(client, KerberosClient))
 
   def test_new_type(self):
@@ -39,20 +38,20 @@ class TestLoad(object):
       def __init__(self, url, bar):
         super(NewClient, self).__init__(url)
         self.bar = bar
-    client = Client.load('NewClient', {'url': 123, 'bar': 2})
+    client = Client._from_options('NewClient', {'url': 123, 'bar': 2})
     eq_(client.bar, 2)
 
   @raises(HdfsError)
   def test_missing_options(self):
-    client = Client.load('KerberosClient', {})
+    client = Client._from_options('KerberosClient', {})
 
   @raises(HdfsError)
   def test_invalid_options(self):
-    client = Client.load(None, {'foo': 123})
+    client = Client._from_options(None, {'foo': 123})
 
   @raises(HdfsError)
   def test_missing_type(self):
-    client = Client.load('foo', {})
+    client = Client._from_options('foo', {})
 
 
 class _TestSession(object):
@@ -76,7 +75,7 @@ class _TestSession(object):
   @classmethod
   def setup_class(cls):
     try:
-      client = get_client_from_alias('test')
+      client = Client.from_alias('test')
       client._delete('', recursive=True)
     except (NoOptionError, NoSectionError, HdfsError):
       cls.client = None
@@ -220,31 +219,6 @@ class TestWrite(_TestSession):
     self.client.write('up', 'hello, world!')
     self.client.write('up/up', 'hello again, world!')
 
-  def test_callback_with_string(self):
-    a = []
-    def callback():
-      a.append(48)
-    self.client.write('up', 'hello', callback=callback)
-    eq_(len(a), 0)
-
-  def test_callback_with_generator(self):
-    a = []
-    def callback():
-      a.append(48)
-    self.client.write('up', (e for e in ['hello', 'world']), callback=callback)
-    eq_(len(a), 2)
-
-  def test_callback_with_file_object(self):
-    a = []
-    def callback():
-      a.append(48)
-    with temppath() as tpath:
-      with open(tpath, 'w') as writer:
-        writer.write('hello, world!\nand a second line')
-      with open(tpath) as reader:
-        self.client.write('up', reader, callback=callback)
-    eq_(len(a), 2)
-
 
 class TestUpload(_TestSession):
 
@@ -290,11 +264,15 @@ class TestDelete(_TestSession):
 
 class TestRead(_TestSession):
 
+  def _read(self, writer, *args, **kwargs):
+    for chunk in self.client.read(*args, **kwargs):
+      writer.write(chunk)
+
   def test_read_file(self):
     self.client.write('foo', 'hello, world!')
     with temppath() as tpath:
       with open(tpath, 'w') as writer:
-        self.client.read('foo', writer)
+        self._read(writer, 'foo')
       with open(tpath) as reader:
         eq_(reader.read(), 'hello, world!')
 
@@ -303,19 +281,19 @@ class TestRead(_TestSession):
     self.client._mkdirs('foo')
     with temppath() as tpath:
       with open(tpath, 'w') as writer:
-        self.client.read('foo', writer)
+        self._read(writer, 'foo')
 
   @raises(HdfsError)
   def test_read_missing_file(self):
     with temppath() as tpath:
       with open(tpath, 'w') as writer:
-        self.client.read('foo', writer)
+        self._read(writer, 'foo')
 
   def test_read_file_from_offset(self):
     self.client.write('foo', 'hello, world!')
     with temppath() as tpath:
       with open(tpath, 'w') as writer:
-        self.client.read('foo', writer, offset=7)
+        self._read(writer, 'foo', offset=7)
       with open(tpath) as reader:
         eq_(reader.read(), 'world!')
 
@@ -323,7 +301,7 @@ class TestRead(_TestSession):
     self.client.write('foo', 'hello, world!')
     with temppath() as tpath:
       with open(tpath, 'w') as writer:
-        self.client.read('foo', writer, offset=7, length=5)
+        self._read(writer, 'foo', offset=7, length=5)
       with open(tpath) as reader:
         eq_(reader.read(), 'world')
 
